@@ -1,7 +1,7 @@
 from ufs_tools.string_tools import class_name_to_low_case
 
 from djangoautoconf.ajax_select_utils.channel_creator_for_model import add_channel_for_models_in_module
-from djangoautoconf.django_rest_framework_utils.serializer_generator import SerializerUrlGenerator
+# from djangoautoconf.django_rest_framework_utils.serializer_generator import SerializerUrlGenerator
 from djangoautoconf.model_utils.tastypie_utils import get_tastypie_urls
 
 
@@ -13,7 +13,7 @@ def add_all_urls(urlpatterns, models):
     except ImportError:
         get_filter_urls = None
         pass
-    urlpatterns = SerializerUrlGenerator(urlpatterns).add_rest_api_urls(models)
+    # urlpatterns = SerializerUrlGenerator(urlpatterns).add_rest_api_urls(models)
     add_channel_for_models_in_module(models)
     return urlpatterns
 
